Welcome to Django Critic’s documentation! — django-critic v0.2.1 documentation

django-critic v0.2.1 documentation

# Welcome to Django Critic’s documentation!

- Table of Contents
- index
  next

# Welcome to Django Critic’s documentation!

Django critic is a generic rating application.

Contents:

- Installation
  - Getting django-critic
  - Installing
- Getting Started
  - Basic settings
  - Create the template
  - Retrieve rating data via urls
  - Add ratings
- Reference
  - Settings
  - API
  - Template Tags

# Indices and tables

- Index
- Module Index
- Search Page